@@ -4,7 +4,7 @@
 
 import glob
 import io
-import json
+import lzma
 import os
 import shlex
 import subprocess
@@ -12,7 +12,7 @@ import sys
 import tarfile
 import time
 from tempfile import NamedTemporaryFile
-from urllib.request import Request
+from urllib.request import Request, urlopen
 
 _plat = sys.platform.lower()
 ismacos = 'darwin' in _plat
@@ -23,19 +23,21 @@ def setenv(key, val):
     os.environ[key] = os.path.expandvars(val)
 
 
-def download_with_retry(url, count=5):
-    from urllib.request import urlopen
-    while count > 0:
-        count -= 1
+def download_with_retry(url: str | Request, count: int = 5) -> bytes:
+    for i in range(count):
         try:
-            print('Downloading', url, flush=True)
+            print('Downloading', getattr(url, 'full_url', url), flush=True)
             with urlopen(url) as f:
-                return f.read()
-        except Exception:
-            if count <= 0:
+                ans: bytes = f.read()
+            return ans
+        except Exception as err:
+            if getattr(err, 'code', -1) == 403:
                 raise
-            print('Download failed retrying...')
+            if i >= count - 1:
+                raise
+            print(f'Download failed with error {err} retrying...', file=sys.stderr)
             time.sleep(1)
+    return b''
 
 
 if ismacos:
@@ -77,7 +79,26 @@ else:
         setenv('CALIBRE_ESPEAK_DATA_DIR', '$SW/share/espeak-ng-data')
 
 
-def run(*args, timeout=600):
+def do_print_crash_reports() -> None:
+    print('Printing available crash reports...', flush=True)
+    if ismacos:
+        end_time = time.monotonic() + 90
+        while time.monotonic() < end_time:
+            time.sleep(1)
+            items = glob.glob(os.path.join(os.path.expanduser('~/Library/Logs/DiagnosticReports'), 'Python-*.ips'))
+            if items:
+                break
+        if items:
+            time.sleep(1)
+            print(os.path.basename(items[0]), flush=True)
+            sdir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
+            subprocess.check_call([sys.executable, os.path.join(sdir, '.github', 'workflows', 'macos_crash_report.py'), items[0]])
+    else:
+        run('sh -c "echo bt | coredumpctl debug"')
+    print(flush=True)
+
+
+def run(*args, timeout=600, print_crash_reports: bool = False):
     if len(args) == 1:
         args = shlex.split(args[0])
     print(' '.join(args), flush=True)
@@ -91,6 +112,8 @@ def run(*args, timeout=600):
         p.kill()
 
     if ret != 0:
+        if print_crash_reports:
+            do_print_crash_reports()
         raise SystemExit(ret)
 
 
@@ -126,7 +149,7 @@ def run_python(*args):
     if len(args) == 1:
         args = shlex.split(args[0])
     args = [python] + list(args)
-    return run(*args)
+    run(*args, print_crash_reports=True)
 
 
 def install_linux_deps():
@@ -144,48 +167,38 @@ def get_tx():
         tf.extract('tx', filter='fully_trusted')
 
 
-def install_grype() -> str:
-    dest = '/tmp'
-    rq = Request('https://api.github.com/repos/anchore/grype/releases/latest', headers={
-        'Accept': 'application/vnd.github.v3+json',
-    })
-    m = json.loads(download_with_retry(rq))
-    for asset in m['assets']:
-        if asset['name'].endswith('_linux_amd64.tar.gz'):
-            url = asset['browser_download_url']
-            break
-    else:
-        raise ValueError('Could not find linux binary for grype')
-    os.makedirs(dest, exist_ok=True)
-    data = download_with_retry(url)
-    with tarfile.open(fileobj=io.BytesIO(data), mode='r') as tf:
-        tf.extract('grype', path=dest, filter='fully_trusted')
-    exe = os.path.join(dest, 'grype')
+def install_grype(exe: str = '/tmp/grype') -> str:
+    raw = download_with_retry('https://download.calibre-ebook.com/ci/grype.xz')
+    raw = lzma.decompress(raw)
+    with open(exe, 'wb') as f:
+        f.write(raw)
+        os.fchmod(f.fileno(), 0o755)
     subprocess.check_call([exe, 'db', 'update'])
     return exe
 
 
 IGNORED_DEPENDENCY_CVES = [
-    # Python stdlib
-    'CVE-2025-8194',   # DoS in tarfile
-    'CVE-2025-6069',   # DoS in HTMLParser
-    'CVE-2025-13836',  # DoS in http client reading from malicious server
-    # glib
-    'CVE-2025-4056',  # Only affects Windows, on which we dont use glib
+    # python stdlib all these are erroneously marked as fixed in python 3.15
+    # when it hasnt even been released. Sigh.
+    'CVE-2026-0865',
+    'CVE-2025-15282',
+    'CVE-2026-0672',
+    'CVE-2025-15366',
+    'CVE-2025-15367',
+    'CVE-2025-12781',
+    'CVE-2025-11468',
     # libtiff
     'CVE-2025-8851',  # this is erroneously marked as fixed in the database but no release of libtiff has been made with the fix
     # hyphen
     'CVE-2017-1000376',  # false match in the database
     # espeak
     'CVE-2023-4990',  # false match because we currently build with a specific commit pending release of espeak 1.53
-    # Qt
-    'CVE-2025-5683',  # we dont use the ICNS image format
     # ffmpeg cannot be updated till Qt starts using FFMPEG 8 and these CVEs are
     # anyway for file types we dont use or support
     'CVE-2025-59733', 'CVE-2025-59731', 'CVE-2025-59732',  # OpenEXR image files, not supported by calibre
     'CVE-2025-59730', 'CVE-2025-59734',  # SANM decoding unused by calibre
     'CVE-2025-59729',  # DHAV files unused by calibre ad negligible security impact: https://issuetracker.google.com/issues/433513232
-    'CVE-2025-11579',  # Go rardecode package probably from grype's own dependencies calibre does not use Go code
+    'CVE-2025-25469', 'CVE-2025-25468',  # memory leak, not a security issue
 ]
 
 
@@ -225,7 +238,7 @@ def check_dependencies() -> None:
     print('Testing against the SBOM', flush=True)
     import runpy
     orig = sys.argv, sys.stdout
-    sys.argv = ['bypy', 'sbom', 'calibre', '1.0.0']
+    sys.argv = ['bypy', 'sbom', 'kovidgoyal/calibre', '1.0.0']
     buf = io.StringIO()
     sys.stdout = buf
     runpy.run_path('bypy-src')
@@ -236,17 +249,28 @@ def check_dependencies() -> None:
 
 
 def main():
+    action = sys.argv[1]
+
+    if action == 'install':
+        # WebEngine is flaky in macOS CI so install rapydscript so bootstrap wont fail
+        npm = 'npm.cmd' if iswindows else 'npm'
+        run(npm, 'install', 'rapydscript-ng')
+        root = subprocess.check_output([npm, 'root']).decode().strip()
+        with open(os.environ['GITHUB_PATH'], 'a') as f:
+            print(os.path.abspath(os.path.join(root, '.bin')), file=f)
+
     if iswindows:
         import runpy
         m = runpy.run_path('setup/win-ci.py')
         return m['main']()
-    action = sys.argv[1]
+
     if action == 'install':
         install_bundle()
         if not ismacos:
             install_linux_deps()
 
     elif action == 'bootstrap':
+        run('rapydscript', '--version')
         install_env()
         run_python('setup.py bootstrap --ephemeral')
 
@@ -283,7 +307,8 @@ username = api
 
         install_env()
         run_python('setup.py test')
-        run_python('setup.py test_rs')
+        if not ismacos:  # webengine is flaky on macOS
+            run_python('setup.py test_rs')
     else:
         raise SystemExit(f'Unknown action: {action}')
 
