@@ -8,7 +8,6 @@ import shutil
 import subprocess
 import sys
 import tempfile
-from contextlib import suppress
 from io import BytesIO
 from threading import Thread
 
@@ -22,7 +21,6 @@ from calibre.utils.filenames import atomic_rename
 from calibre.utils.imghdr import what
 from calibre.utils.resources import get_image_path as I
 from calibre_extensions import imageops
-from polyglot.builtins import string_or_bytes
 
 
 # Utilities {{{
@@ -107,9 +105,8 @@ def gif_data_to_png_data(data, discard_animation=False):
 # Loading images {{{
 
 def set_image_allocation_limit(size_in_mb=1024):
-    with suppress(ImportError):  # for people running form source
-        from calibre_extensions.progress_indicator import set_image_allocation_limit as impl
-        impl(size_in_mb)
+    from calibre_extensions.progress_indicator import set_image_allocation_limit as impl
+    impl(size_in_mb)
 
 
 def null_image():
@@ -123,7 +120,7 @@ def image_from_data(data):
         return data
     set_image_allocation_limit()
     i = QImage()
-    if not i.loadFromData(data):
+    if not imageops.load_from_data_without_gil(i, data):
         q = what(None, data)
         if q == 'jxr':
             return load_jxr_data(data)
@@ -159,7 +156,10 @@ def image_and_format_from_data(data):
     buf.open(QIODevice.OpenModeFlag.ReadOnly)
     r = QImageReader(buf)
     fmt = bytes(r.format()).decode('utf-8')
-    return r.read(), fmt
+    ans = r.read()
+    buf.close()
+    del r
+    return ans, fmt
 # }}}
 
 
@@ -515,7 +515,7 @@ def quantize_image(img, max_colors=256, dither=True, palette=''):
     img = image_from_data(img)
     if img.hasAlphaChannel():
         img = blend_image(img)
-    if palette and isinstance(palette, string_or_bytes):
+    if palette and isinstance(palette, (str, bytes)):
         palette = palette.split()
     return imageops.quantize(img, int(max_colors), dither, tuple(QColor(x).rgb() for x in palette))
 
